IDOM
====

Libraries for defining and controlling interactive webpages with Python
3.7 and above.

.. toctree::
    :hidden:

    installation
    getting-started
    life-cycle-hooks
    core-concepts
    javascript-components
    specifications
    package-api
    examples

.. toctree::
    :hidden:
    :caption: Development

    contributing
    developer-guide

.. toctree::
    :hidden:
    :caption: External Resources

    Source Code <https://github.com/idom-team/idom>
    Community <https://github.com/idom-team/idom/discussions>
    Issues <https://github.com/idom-team/idom/issues>



At a Glance
-----------

Let's use IDOM to create a simple slideshow which changes whenever a
user clicks an image:

.. example:: slideshow

Try selecting the "Live Example" tab in the view above and enabling the widget.

Once activated try clicking the displayed image to make it change 🖱️
